From: "Krishnakumar. R" <krishnakumar@naturesoft.net>
To: Andrew Morton <akpm@osdl.org>
Cc: linux-kernel@vger.kernel.org
Subject: [PATCH-2.6.0-test5-mm1] conversion of schedule_task to schedule_work
Date: Thu, 11 Sep 2003 16:32:14 +0530 [thread overview]
Message-ID: <200309111632.14197.krishnakumar@naturesoft.net> (raw)
Hi,
The following patch converts one 'schedule_task'
in the code, and one 'schedule_task' in a comment
to 'schedule_work'. The file changed is drivers/char/istallion.c
The patch applies against 2.6.0-test5-mm1.
Regards
KK
============================
Compilation Warning removed:
drivers/char/istallion.c:2947: warning: implicit declaration of function `schedule_task'
drivers/char/istallion.c: In function `stli_startbrd':
Linking warning removed:
drivers/built-in.o(.text+0x25e73): In function `stli_poll':
: undefined reference to `schedule_task'
=============================
diffstat output:
istallion.c | 4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)
=============================
The following is the patch:
--- linux-2.6.0-test5-mm1/drivers/char/istallion.orig.c 2003-09-11 14:51:35.000000000 +0530
+++ linux-2.6.0-test5-mm1/drivers/char/istallion.c 2003-09-11 14:52:06.000000000 +0530
@@ -2303,7 +2303,7 @@
/*
* FIXME: There's a module removal race here: tty_hangup
* calls schedule_task which will call into this
* driver later.
*/
portp = (stliport_t *) arg;
@@ -2944,7 +2944,7 @@
((portp->sigs & TIOCM_CD) == 0)) {
if (portp->flags & ASYNC_CHECK_CD) {
if (tty)
- schedule_task(&portp->tqhangup);
+ schedule_work(&portp->tqhangup);
}
}
}
reply other threads:[~2003-09-11 10:58 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=200309111632.14197.krishnakumar@naturesoft.net \
--to=krishnakumar@naturesoft.net \
--cc=akpm@osdl.org \
--cc=linux-kernel@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -2303,7 +2303,7 @@
/*
* FIXME: There's a module removal race here: tty_hangup
- * calls schedule_task which will call into this
+ * calls schedule_work which will call into this
* driver later.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox